//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraOptions](index.md)/[hasRenpuuJyantouHu](has-renpuu-jyantou-hu.md)

# hasRenpuuJyantouHu

[common]\
val [hasRenpuuJyantouHu](has-renpuu-jyantou-hu.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

连风雀头是否记4符（true则记4符，false则记2符）
